<?php

/* SIMPLE CAPTCHA
-------------------------------------*/

define('CAP_PATH', dirname(__file__) . '/');

class captcha {

  static $cfg = [
    // Length of code
    // If you increase this, make sure image width/height can accomodate all characters..
    'length' => 8,
    
    // Use word list..if yes, length above is ignored, therefore words must be set that
    // fit on the captcha. eg: if 8 was set above initially, words should not contain more
    // than 8 chars
    'word_list' => 'no',
    
    // Location of word list file relative the class
    'word_list_loc' => 'control/classes/_captcha_word_list.txt',
    
    // Size of captcha image..
    'image-size' => [130,50],
    
    // Background color (R,G,B)
    'bg-color' => [239, 239, 239],
    
    // Text color (R,G,B)
    'txt-color' => [85, 85, 85],
    
    // Line color (R,G,B)
    'line-color' => [176, 150, 184],
    
    // How many lines? 0 for no lines.
    'line-count' => 5,
    
    // Pixel color (R,G,B)
    'pixel-color' => [221, 221, 221],
    
    // How many pixels? 0 for no pixels.
    'pixel-count' => 1000,
    
    // Font..must exist in contents fonts folder..
    'font' => 'content/fonts/Comfortaa-Light.ttf',
    
    // Font size..
    'font-size' => 15,
    
    // Positions..
    'pos' => [
      'x' => [15, 15],
      'y' => [35, 35]
    ],
    
    // Random angle..
    'angle' => [-5, 10],
    
    // Image content type..
    // image/jpeg or image/png
    'content-type' => 'image/jpeg'
  ];
  
  public static function code() {
    switch(captcha::$cfg['word_list']) {
      case 'yes':
        if (file_exists(CAP_PATH . captcha::$cfg['word_list_loc'])) {
          $read = array_map('trim', captcha::words());
          shuffle($read);
          $code = (isset($read[0]) && $read[0] ? $read[0] : captcha::rand());
        } else {
          $code = captcha::rand();
        }
        break;
      default:
        $code = captcha::rand();
        break;
    }
    $_SESSION['captcha_' . sha1(SECRET_KEY)] = $code;
    return $code;
  }
  
  private static function rand() {
    $code = '';
    $upper = range('A','Z');
    $lower = range ('a','z');
    $num = range(0,9);
    $all = array_merge($upper, $lower, $num);
    shuffle($all);
    if (captcha::$cfg['length'] > 62) {
      captcha::$cfg['length'] = 7;
    }
    for ($i=0; $i<captcha::$cfg['length']; $i++) {
      $code .= $all[rand(10,40)];
    }
    return $code;
  }
  
  private static function create($code) {
    // Draw captcha..
    if (function_exists('imagecreatetruecolor')) {
      $layer = imagecreatetruecolor(captcha::$cfg['image-size'][0],captcha::$cfg['image-size'][1]);
      $bg    = imagecolorallocate($layer, captcha::$cfg['bg-color'][0], captcha::$cfg['bg-color'][1], captcha::$cfg['bg-color'][2]);
      $color = imagecolorallocate($layer, captcha::$cfg['txt-color'][0], captcha::$cfg['txt-color'][1], captcha::$cfg['txt-color'][2]);
      $pixel = imagecolorallocate($layer, captcha::$cfg['pixel-color'][0], captcha::$cfg['pixel-color'][1], captcha::$cfg['pixel-color'][2]);
      $line  = imagecolorallocate($layer, captcha::$cfg['line-color'][0], captcha::$cfg['line-color'][1], captcha::$cfg['line-color'][2]);
      if (file_exists(PATH . captcha::$cfg['font'])) {
        imagefill($layer, 0, 0, $bg);
        if (captcha::$cfg['line-count'] > 0) {
          for ($i=0; $i<captcha::$cfg['line-count']; $i++) {
            imageline($layer, 0, rand() % 50, 200, rand() % 50, $line);
          }
        }
        if (captcha::$cfg['pixel-count'] > 0) {
          for ($i=0; $i<captcha::$cfg['pixel-count']; $i++) {
            imagesetpixel($layer, rand() % 200, rand() % 50, $pixel);
          }
        }
        imagettftext(
          $layer,
          captcha::$cfg['font-size'],
          mt_rand(captcha::$cfg['angle'][0],captcha::$cfg['angle'][1]),
          mt_rand(captcha::$cfg['pos']['x'][0],captcha::$cfg['pos']['x'][1]),
          mt_rand(captcha::$cfg['pos']['y'][0],captcha::$cfg['pos']['y'][1]),
          $color, PATH . captcha::$cfg['font'],
          $code
        );
        return $layer;
      }
    }
    return '';
  }
  
  public static function words() {
    return file(CAP_PATH . captcha::$cfg['word_list_loc']);
  }
  
  public static function show($code) {
    $c = captcha::create($code);
    if ($c) {
      header("Content-type: " . captcha::$cfg['content-type']);
      switch(captcha::$cfg['content-type']) {
        case 'image/jpeg':
          imagejpeg(captcha::create($code));
          break;
        default:
          imagepng(captcha::create($code));
          break;
      }
      imagedestroy($c);
      exit;
    } else {
      return '--';
    }
  }
  
  public static function check() {
    return (isset($_SESSION['captcha_' . sha1(SECRET_KEY)]) ?
      $_SESSION['captcha_' . sha1(SECRET_KEY)]
      : ''
    );
  }

}

?>