<?php

/* CLASS FILE
----------------------------------*/

define('SYS_ROOT_PATH', __dir__ . '/../../../');

include(SYS_ROOT_PATH . 'control/classes/mailer/src/Exception.php');
include(SYS_ROOT_PATH . 'control/classes/mailer/src/SMTP.php');
include(SYS_ROOT_PATH . 'control/classes/mailer/src/PHPMailer.php');

class mmMailer extends PHPMailer\PHPMailer\PHPMailer {

  public $vars = [];

  public $smtp_host;
  public $smtp_port;
  public $smtp_user;
  public $smtp_pass;
  public $smtp_fname;
  public $smtp_femail;
  public $smtp_en;

  public $smtp_sec = ''; // tls, ssl or blank

  // Mail debug log..
  private $debug = 'no';
  private $debug_log_file = 'mail-debug-log.log';

  // Allow insecure connections..
  // Use at your own risk..
  // yes or no value
  private $allowInsecure = 'no';
  
  // Preferred language
  // Must be supported language
  private $mail_lang = 'en';

  // Cleans slashes..
  public function _mmClean($data) {
    return $data;
  }

  // Converts entities..
  public function convertChar($data) {
    $find    = array('&#039;','&quot;','&amp;','&lt;','&gt;');
    $replace = array('\'','"','&','<','>');

    return str_replace($find,$replace,$data);
  }

  // Loads tags into array..
  public function addTag($placeholder,$data) {
    $this->vars[$placeholder] = $data;
  }

  // Clears data vars..
  public function clearVars() {
    $this->vars = array();
  }

  // Converts tags..
  public function convertTags($data) {
    if (!empty($this->vars)) {
      foreach ($this->vars AS $tags => $value) {
        $data = str_replace($tags,$value,$data);
      }
    }

    return $data;
  }

  // Mail headers..
  public function _headers($name,$email) {
    global $mail_charset;
    $headers  = "Content-type: text/plain; charset=" . (isset($mail_charset) && $mail_charset ? $mail_charset : 'utf-8') . "\r\n";
    $headers .= "From: \"".$this->injectionCleaner($name)."\" <".$email.">\n";
    $headers .= "X-Sender: \"".$this->injectionCleaner($name)."\" <".$email.">\n";
    $headers .= "X-Mailer: PHP\n";
    $headers .= "X-Priority: 3\n";
    $headers .= "X-Sender-IP: ".$_SERVER['REMOTE_ADDR']."\n";
    $headers .= "Date: ".date("r")."\n";
    $headers .= "Return-Path: \"".$this->injectionCleaner($name)."\" <".$email.">\n";
    $headers .= "Reply-To: \"".$this->injectionCleaner($name)."\" <".$email.">\n";
    return $headers;
  }

  // Cleans spam/form injection input..
  public function injectionCleaner($data) {
    $find = [
     "\r",
     "\n",
     "%0a",
     "%0d",
     "content-type:",
     "Content-Type:",
     "BCC:",
     "CC:",
     "boundary=",
     "TO:",
     "bcc:",
     "to:",
     "cc:"
     ];
    $replace = [];
    return str_replace($find,$replace,$data);
  }

  // Loads e-mail template..
  public function template($file) {
    $tmp = trim(file_get_contents($file));
    return ($tmp ? 
      trim($this->convertTags($tmp)) : 
      'An error occurred opening the <b>' . $file . '</b> file. Check that this file exists in the correct "content/lang/email/" folder!'
    );
  }

  // Sends mail..
  // If you are testing the script on localhost and you don`t have mail
  //  capabilities, set the $email var to false to disable mail sending.
  public function sendMail($to_name,$to_email,$from_name,$from_email,$subject,$msg,$email=true) {
    if ($email) {
      // Additional stripping of too many chars..ie: spammers
      $to_name     = substr($to_name,0,250);
      $to_email    = substr($to_email,0,250);
      $from_name   = substr($from_name,0,250);
      $from_email  = substr($from_email,0,250);
      if ($this->smtp_en == 'yes') {
        $this->IsSMTP();
        $this->IsHTML(false);
        $this->Port       = $this->smtp_port;
        $this->Host       = $this->smtp_host;
        $this->SMTPAuth   = ($this->smtp_user && $this->smtp_pass ? true : false);
        $this->SMTPSecure = (in_array($this->smtp_sec, array(
          '',
          'tls',
          'ssl'
        )) ? $this->smtp_sec : '');
        // Allow insecure connections?
        if ($this->allowInsecure == 'yes') {
          $this->SMTPOptions = array(
            'ssl' => array(
              'verify_peer' => false,
              'verify_peer_name' => false,
              'allow_self_signed' => true
            )
          );
        }
        $this->Username   = $this->smtp_user;
        $this->Password   = $this->smtp_pass;
        $this->From       = $this->smtp_femail;
        $this->FromName   = $this->convertChar($this->_mmClean($this->injectionCleaner($this->smtp_fname)));
        $this->addAddress($to_email, $this->convertChar($this->_mmClean($this->injectionCleaner($to_name))));
        $this->addReplyTo($from_email, $from_name);
        $this->WordWrap   = 1000;
        $this->CharSet    = 'utf-8';
        // Enable debug..
        if ($this->debug == 'yes') {
          $this->SMTPDebug = 2;
          $this->Debugoutput = function($str, $level) {
            file_put_contents(SYS_ROOT_PATH . 'logs/' . $this->debug_log_file, $str . PHP_EOL, FILE_APPEND);
          };
        }
        // Language
        if ($this->mail_lang != 'en') {
          $this->setLanguage($this->mail_lang, SYS_ROOT_PATH . 'control/classes/mailer/language/');
        }
        $this->Subject    = $this->convertChar($this->_mmClean($subject));
        $this->Body       = $this->convertChar($this->_mmClean($msg));
        $this->Send();
      } else {
        mail($to_email,
          $this->convertChar($this->_mmClean($subject)),
          $this->convertChar($this->_mmClean($msg)),
          $this->_headers($this->_mmClean($this->convertChar($from_name)),$from_email)
        );
      }
    }
  }

}

?>
