<?php

/* RECIPE SYSTEM
==============================================*/

header('Expires: Sun, 01 Jan 2014 00:00:00 GMT');
header('Cache-Control: no-store, no-cache, must-revalidate');
header('Cache-Control: post-check=0, pre-check=0', FALSE);
header('Pragma: no-cache');
header('Content-type: text/html; charset=utf-8');
if (isset($_SERVER['HTTP_USER_AGENT']) && (strpos($_SERVER['HTTP_USER_AGENT'], 'MSIE') !== false)) {
  header('X-UA-Compatible: IE=edge,chrome=1');
}

@session_start();

// Set path to recipe folder
define('PATH', __dir__.'/');
define('PARENT', 1);

// Check cfg
if (!file_exists(PATH . 'control/_cfg.php')) {
  die('Config file missing, please read installation instructions');
}

include(PATH . 'control/_cfg.php');
date_default_timezone_set((TIMEZONE ? TIMEZONE: (function_exists('date_default_timezone_get') ? date_default_timezone_get() : 'Europe/London')));

if (version_compare(phpversion(), '7.0', '<')) {
  die('PHP version too old, PHPv7 or higher required');
}

// Enable debugger
echo (!function_exists('json_decode') ? die('The JSON functions are not enabled on your server. Enable and restart server. If you are unsure please contact your host.') : '');

include(PATH . 'control/options.php');
if (version_compare(PHP_VERSION, '8.0.0') >= 0) {
  include(PATH . 'control/lib/tracy/vendor/tracy/tracy/src/tracy.php');
}
use Tracy\Debugger;
if (version_compare(PHP_VERSION, '8.0.0') >= 0) {
  // For development, report everything and enable tracy bar
  Debugger::$showBar = (defined('DEVELOPMENT_ENV') ? true : false);
  Debugger::$strictMode = (defined('DEVELOPMENT_ENV') ? true : false);
  Debugger::$errorTemplate = PATH . 'control/500-debug.php';
  Debugger::enable(Debugger::DEVELOPMENT, PATH . 'logs');
}

// Load Settings Data..
$q = mysqli_query($GLOBALS["___mysqli_ston"], "SELECT * FROM `" . DB_PREFIX . "settings` LIMIT 1");
if ($q) {
  $SETTINGS = mysqli_fetch_object($q);
  if (!isset($SETTINGS->language)) {
    die('Fatal error, run installer again');
  }
  if (!isset($SETTINGS->smtp_fname)) {
    die('Your database is not running the latest version, try the upgrade option in the docs');
  }
} else {
  header("Location: install/index.php");
  exit;
}

// Load include files..
include(PATH . 'control/functions.php');
include(PATH . 'control/lib/Savant3.php');
include(PATH . 'control/classes/mailer/class.mail.php');
include(PATH . 'control/classes/class.recipes.php');
include(PATH . 'control/classes/class.categories.php');
include(PATH . 'control/classes/class.rss.php');
include(PATH . 'control/classes/class.json.php');
include(PATH . 'control/classes/class.page.php');
include(PATH . 'control/classes/class.captcha.php');
include(PATH . 'control/classes/class.mobile-detection.php');
include(PATH . 'control/classes/class.tags.php');

//Load language file
include(PATH . 'content/lang/' . ($SETTINGS->language && file_exists(PATH . 'content/lang/' . $SETTINGS->language) ? $SETTINGS->language : 'english.php'));

// Check .htaccess file is in place if mod_rewrite is enabled..
if ($SETTINGS->modr=='yes' && !file_exists(PATH . '.htaccess')) {
  echo $script22;
  exit;
}

// Variables
$cmd                  = (isset($_GET['p']) ? $_GET['p'] : 'home');
$page                 = (isset($_GET['next']) ? (int) $_GET['next'] : '1');
$limit                = $page * $SETTINGS->total - ($SETTINGS->total);
$count                = 0;
$loadJS               = [];
$formErrors           = [];
$eImgError            = [];
$lKey                 = _mmEncrypt('mra_' . $SETTINGS->email . '_' . _mmEncrypt(SECRET_KEY));

// Create class objects..
$MRMAIL               = new mmMailer();
$PDTC                 = new Detection\MobileDetect();
$MRMAIL->smtp_en      = $SETTINGS->smtp;
$MRMAIL->smtp_host    = $SETTINGS->smtp_host;
$MRMAIL->smtp_user    = $SETTINGS->smtp_user;
$MRMAIL->smtp_pass    = $SETTINGS->smtp_pass;
$MRMAIL->smtp_port    = $SETTINGS->smtp_port;
$MRMAIL->smtp_fname   = $SETTINGS->smtp_fname;
$MRMAIL->smtp_femail  = $SETTINGS->smtp_femail;
$MRMAIL->addTag('{WEBSITE_NAME}',$SETTINGS->website);
$MRMAIL->addTag('{WEBSITE_URL}',$SETTINGS->install_path);
$MRMAIL->addTag('{WEBSITE_EMAIL}',$SETTINGS->email);
$MRMAIL->addTag('{DATE}',date(PHP_DATE_FORMAT,strtotime(SERVER_TIME_ADJUSTMENT)));
$MRMAIL->addTag('{IP}', _mmIP());

// CSRF Token
if (!isset($_SESSION['token_' . sha1($SETTINGS->email . SECRET_KEY)])) {
  $_SESSION['token_' . sha1($SETTINGS->email . SECRET_KEY)] = _mmToken();
}

// Default text for title..
$headerTitleText = str_replace('{website_name}',_mmHTML($SETTINGS->website),$ps_header9);

// Ajax
if (isset($_GET['aj'])) {
  include(PATH . 'control/ajax.php');
  exit;
}

// If comments are enabled and being added, a post request is sent via ajax..
// Tell system which area to load..
if (isset($_POST['r'])) {
  $cmd='add-comments';
}

// Logout
if (isset($_GET['lo'],$_SESSION[$lKey])) {
  $_SESSION[$lKey] = '';
  unset($_SESSION[$lKey]);
  header("Location: " . ($SETTINGS->modr=='yes' ? 'add-recipe.html' : '?p=add-recipe'));
  exit;
}

// Platform detection
define('MSW_PFDTCT', ($PDTC->isMobile() ? ($PDTC->isTablet() ? 'tablet' : 'mobile') : 'pc'));

// Main processing switch statement..
switch ($cmd) {
    // content/home.tpl.php
  case 'home':
  case '404':

    // Redirect for search..
    if (isset($_POST['search'], $_POST['keys'])) {
      // Clean the form input..
      $newKeys  = strip_tags($_POST['keys']);
      if ($newKeys && $newKeys!=$ps_header13) {
        if ($SETTINGS->modr=='yes') {
          header("Location: ".$SETTINGS->install_path . "search-free-recipes/" . urlencode($newKeys) . "/all/1/index.html");
        } else {
          header("Location: ?p=search-free-recipes&keys=" . urlencode($newKeys) . "&cat=all");
        }
        exit;
      }
      header("Location: ".$SETTINGS->install_path.($SETTINGS->modr=='yes' ? 'index.html' : 'index.php'));
      exit;
    }

    include(PATH . 'control/header.php');

    // Categories
    $catList = categories::build($SETTINGS);

    $tpl = new Savant3();
    $tpl->assign('WELCOME_TXT', ($cmd=='404' ? $ps_index6 : str_replace('{website_name}',_mmHTML($SETTINGS->website),$ps_index)));
    $tpl->assign('WELCOME_MSG', ($cmd=='404' ? $ps_index7 : $ps_index2));
    $tpl->assign('CATEGORIES_TXT', $ps_index3);
    $tpl->assign('CATEGORIES_LEFT', $catList['left']);
    $tpl->assign('CATEGORIES_RIGHT', $catList['right']);
    $tpl->assign('LATEST_RECIPES_TXT', $ps_index4);
    $tpl->assign('LATEST_RECIPES', recipes::latest_popular('latest', $SETTINGS));
    $tpl->assign('MOST_POPULAR_TXT', $ps_index5);
    $tpl->assign('MOST_POPULAR', recipes::latest_popular('popular', $SETTINGS));
    $tpl->assign('FILTER_BY_TXT', $ps_search4);
    $tpl->assign('H_URL', ($SETTINGS->modr=='yes' ? 'index.html' : 'index.php'));
    $tpl->assign('LOAD_CONTRIBUTORS', recipes::contributors('',$SETTINGS));
    $tpl->assign('HEAD_CLASS', ($cmd=='404' ? 'errorHeadLeft' : 'headLeft'));
    $tpl->assign('RSS', ($SETTINGS->enRSS=='yes' ? '<a href="'.($SETTINGS->modr=='yes' ? 'rss-feed.html' : '?p=rss-feed').'" onclick="window.open(this);return false">'.$ps_header10.'</a></span>'._mmNL() : '')); 
    $tpl->assign('CURRENTLY_LISTING', str_replace(array('{rcount}','{ccount}'),array(number_format((float) _mmSQLRows('recipes',' WHERE `isApproved` = \'no\' AND `enRecipe` = \'yes\'')),_mmSQLRows('categories',' WHERE `enCat` = \'yes\'')),$ps_header5));
    $tpl->assign('KEYWORDS', (isset($_GET['keys']) && $_GET['keys'] ? _mmHTML($_GET['keys']) : ''));
    $tpl->assign('PLACEHOLDER', _mmHTML($ps_header13));
    $tpl->display('content/index.tpl.php');

    include(PATH . 'control/footer.php');
    break;

  // content/recipe.tpl.php
  case 'recipe':

    // Load ibox...
    $loadJS[] = 'recipes';

    if (!isset($_GET['recipe'])) {
      header("Location: ".$SETTINGS->install_path.($SETTINGS->modr=='yes' ? 'index.html' : 'index.php'));
      exit;
    }

    // Check query var digit..
    _mmDigit($_GET['recipe']);

    // Get recipe/category information..
    $RECIPE  = _mmSQLTable('recipes','id',$_GET['recipe']);

    // Does recipe exist..
    if (!isset($RECIPE->id)) {
      header("Location: ".$SETTINGS->install_path.($SETTINGS->modr=='yes' ? '404.html' : 'index.php?p=404'));
      exit;
    }

    // Increment hit count..
    if (ENABLE_HIT_COUNT) {
    recipes::hits();
    }

    // Is recipe enabled..if not, go back to homepage..
    // You can pop an alternative redirect here or display a 404..
    if ($RECIPE->enRecipe=='no' || $RECIPE->isApproved=='yes') {
      header("Location: ".$SETTINGS->install_path.($SETTINGS->modr=='yes' ? 'index.html' : 'index.php'));
      exit;
    }

    // Overwrite meta data..
    if ($RECIPE->metaKeys) {
      $overRideMetaKeys = _mmHTML($RECIPE->metaKeys);
    }
    if ($RECIPE->metaDesc) {
      $overRideMetaDesc = _mmHTML($RECIPE->metaDesc);
    }

    // Rewrite page title..
    $headerTitleText = str_replace(
      array('{recipe}','{website_name}'),
      array(_mmHTML($RECIPE->name),$SETTINGS->website),
      $ps_header11
    );

    // Load pictures js..
    if (_mmSQLRows('pictures', ' WHERE `recipe` = \''.(int)$_GET['recipe'].'\'')>0) {
      $loadJS[] = 'pictures';
      define('SPLIDE', 1);
    }

    // Url
    if ($SETTINGS->modr=='yes') {
      $link  = $SETTINGS->install_path . 'free-recipe/' . _mmURL($RECIPE->name) . '/' . $RECIPE->id . '/index.html';
    } else {
      $link  = $SETTINGS->install_path . '?p=recipe&amp;recipe=' . $RECIPE->id;
    }

    $og_data = [];
    $qOG       = mysqli_query($GLOBALS["___mysqli_ston"], "SELECT `picPath` FROM `" . DB_PREFIX . "pictures`
        WHERE `recipe` = '".(int)$_GET['recipe']."'
        ORDER BY rand()
        LIMIT 1
        ");
    $OG_PIC = mysqli_fetch_object($qOG);
    if (isset($OG_PIC->picPath)) {
      if (file_exists(PATH . 'content/images/recipes/'.$OG_PIC->picPath)) {
        $og_data['pic'] = $SETTINGS->install_path . 'content/images/recipes/'.$OG_PIC->picPath;
        $og_data['sizes'] = getimagesize(PATH . 'content/images/recipes/'.$OG_PIC->picPath);
      }
      $og_data['name'] = _mmHTML($RECIPE->name);
      $og_data['url'] = $link;
    }

    include(PATH . 'control/header.php');

    // For contributor url..
    if ($SETTINGS->modr=='yes') {
      $conUrl = $SETTINGS->install_path . 'search-free-recipes/chef::' . urlencode($RECIPE->submitted_by) . '/all/1/index.html';
    } else {
      $conUrl = '?p=search-free-recipes&amp;keys=chef::' . urlencode($RECIPE->submitted_by) . '&amp;cat=all';
    }

    $tpl = new Savant3();
    $tpl->assign('RECIPE', $RECIPE);
    $tpl->assign('RECIPE_LINKS_TXT', $ps_recipe);
    $tpl->assign('ADD_COMMENT', ($RECIPE->enComments=='yes' ? recipes::comments_form($ps_recipe3,$SETTINGS) : ''));
    $tpl->assign('JUMP_TO_CATEGORY_TXT', $ps_recipe4);
    $tpl->assign('RECIPE_SELECTION_TXT', $ps_recipe5);
    $tpl->assign('PICTURES_TXT', $ps_recipe6);
    $tpl->assign('SHOW_PICTURES', recipes::recipe_pictures($ps_recipe18,$SETTINGS));
    $tpl->assign('COMMS_TEXT', $ps_recipe7);
    $tpl->assign('VISITOR_COMMENTS', ($RECIPE->enComments=='yes' ? recipes::recipe_comments($ps_recipe15,$ps_recipe16,$ps_recipe7,$SETTINGS) : ''));
    $tpl->assign('HITS_TXT', (ENABLE_HIT_COUNT ? $ps_recipe19 : ''));
    $tpl->assign('CONTACT_US_TXT', $ps_recipe8);
    $tpl->assign('PRINT_FRIENDLY_TXT', $ps_recipe10);
    $tpl->assign('SUBMITTED_BY', '<a href="'.$conUrl.'" class="chef">'._mmHTML($RECIPE->submitted_by).'</a>');
    $tpl->assign('DATE_BAR_TXT', $RECIPE->adate);
    $tpl->assign('INGREDIENTS_TXT', $ps_recipe11);
    $tpl->assign('INSTRUCTIONS_TXT', $ps_recipe12);
    $tpl->assign('SUBMIT_TXT', $ps_recipe14);
    $tpl->assign('SOCIAL', [
    'url' => $link,
    'title' => urlencode(_mmHTML($RECIPE->name))
    ]);
    $tpl->assign('S_URL', $SETTINGS->install_path.($SETTINGS->modr=='yes' ? 'add-recipe/index.html' : '?p=add-recipe'));
    $tpl->assign('C_URL', $SETTINGS->install_path.($SETTINGS->modr=='yes' ? 'contact-recipe/'.$_GET['recipe'].'/index.html' : '?p=contact-recipe&amp;recipe='.$_GET['recipe']));
    $tpl->assign('P_URL', $SETTINGS->install_path.($SETTINGS->modr=='yes' ? 'print/'.$_GET['recipe'].'/index.html' : '?p=print&amp;recipe='.$_GET['recipe']));
    $tpl->assign('H_URL', ($SETTINGS->modr=='yes' ? 'index.html' : 'index.php'));
    $tpl->assign('KEYWORDS', (isset($_GET['keys']) && $_GET['keys'] ? _mmHTML($_GET['keys']) : ''));
    $tpl->assign('PLACEHOLDER', _mmHTML($ps_header13));
    $tpl->assign('LOAD_CATEGORIES', categories::category_select(false,$SETTINGS));
    $tpl->assign('FILTER_BY_TXT', $ps_search4);
    $tpl->assign('LOAD_CONTRIBUTORS', recipes::contributors('',$SETTINGS));
    $tpl->assign('OTHER_RECIPES_IN_CATEGORY', recipes::recipe_category_other($ps_recipe13, getRecCats($_GET['recipe']),$SETTINGS));
    $tpl->assign('VARS', $vars);
    $tpl->display('content/recipe.tpl.php');

    include(PATH . 'control/footer.php');
    break;

  // content/category.tpl.php
  case 'category':

    // Check query var digit..
    _mmDigit($_GET['cat']);

    // Get cat data..
    $CAT = _mmSQLTable('categories','id',$_GET['cat']);

    // Does cat exist..
    if (!isset($CAT->id)) {
      header("Location: ".$SETTINGS->install_path . ($SETTINGS->modr=='yes' ? '404.html' : 'index.php?p=404'));
      exit;
    }

    // Is category enabled..
    if ($CAT->enCat=='no') {
      header("Location: ".$SETTINGS->install_path . ($SETTINGS->modr=='yes' ? '404.html' : 'index.php?p=404'));
      exit;
    }

    // Is category parent..
    if ($CAT->isParent=='no') {
      $thisParent = _mmSQLTable('categories','id',$CAT->childOf);
      // Is category enabled..
      if ($thisParent->enCat=='no') {
        header("Location: ".$SETTINGS->install_path . ($SETTINGS->modr=='yes' ? '404.html' : 'index.php?p=404'));
        exit;
      }
    }

    // Overwrite meta data..
    if ($CAT->metaKeys) {
      $overRideMetaKeys = _mmHTML($CAT->metaKeys);
    }
    if ($CAT->metaDesc) {
      $overRideMetaDesc = _mmHTML($CAT->metaDesc);
    }

    // Display based on whether cat is parent or child..
    $headerTitleText = (isset($thisParent->catname) ?
    str_replace(array('{cat}','{subcat}'),array(_mmHTML($CAT->catname),_mmHTML($thisParent->catname)),$ps_category2) :
    str_replace('{cat}',_mmHTML($CAT->catname),$ps_category)).' '.$headerTitleText;

    // Recipe count..
    $rCount = categories::category_recipes('', true, $SETTINGS);

    // Also include child recipe count for parents?
    if (!isset($thisParent->catname) && PARENT_WITH_CHILD_COUNT) {
      $ourChildren = categories::children($_GET['cat']);
      $rCount = $rCount+(!empty($ourChildren) ? _mmSQLRows('recipes LEFT JOIN `' . DB_PREFIX . 'recipe_cats` ON `' . DB_PREFIX . 'recipes`.`id` = `' . DB_PREFIX . 'recipe_cats`.`recipe`',' WHERE `' . DB_PREFIX . 'recipe_cats`.`category` IN ('.implode(',',$ourChildren).') AND `enRecipe` = \'yes\' AND `isApproved` = \'no\'') : 0);
    }

    // Determine pagination..
    if ($SETTINGS->modr=='yes') {
      if (isset($thisParent->catname)) {
        $link = $SETTINGS->install_path . 'category/' . _mmURL($thisParent->catname) . '/' . _mmURL($CAT->catname) . '/' . $CAT->id . '/{page}/index.html';
      } else {
        $link = $SETTINGS->install_path . 'category/' . _mmURL($CAT->catname) . '/' . $CAT->id . '/{page}/index.html';
      }
      $pLink = $link;
    } else {
      $pLink = '?p=category&amp;next=';
    }

    $pNumbers = new pages([
      'count' => $rCount,
      'text' => $vars['pagination'],
      'page' => $page,
      'limit' => $SETTINGS->total,
      'url' => $pLink,
      's' => $SETTINGS
    ]);

    include(PATH . 'control/header.php');

    $tpl = new Savant3();
    $tpl->assign('VIEWING_CAT_TXT', str_replace(array('{cat}','{count}'),array((isset($thisParent->catname) ? _mmHTML($thisParent->catname).' / ' : '')._mmHTML($CAT->catname),$rCount),$ps_category3));
    $tpl->assign('PLEASE_CHOOSE_TXT', ($rCount>0 ? ($CAT->comments ? _mmHTML($CAT->comments) : $ps_category6) : $ps_category7));
    $tpl->assign('RECIPES', categories::category_recipes('',false,$SETTINGS));
    $tpl->assign('CAT_RSS', rss::rss_cat_link($_GET['cat'],$SETTINGS));
    $tpl->assign('COUNT', $rCount);
    $tpl->assign('PAGE_NUMBERS', $pNumbers->display());
    $tpl->assign('OTHER_CATS_TXT', $ps_category4);
    $tpl->assign('OTHER_CATS', categories::categories_related($_GET['cat'],[],$SETTINGS));
    $tpl->assign('RECIPE_SELECTION_TXT', $ps_category5);
    $tpl->assign('RECIPE_SELECTION', categories::category_group_popular($_GET['cat'],$SETTINGS));
    $tpl->assign('LOAD_CONTRIBUTORS', recipes::contributors($_GET['cat'],$SETTINGS));
    $tpl->assign('PLACEHOLDER', _mmHTML($ps_header13));
    $tpl->assign('FILTER_BY_TXT', $ps_search4);
    $tpl->assign('H_URL', ($SETTINGS->modr=='yes' ? 'index.html' : 'index.php'));
    $tpl->assign('KEYWORDS', '');
    $tpl->display('content/category.tpl.php');

    include(PATH . 'control/footer.php');
    break;

  // content/add-recipe.tpl.php
  case 'add-recipe':

    if ($SETTINGS->addRecipe == 'no') {
      header("Location: ".$SETTINGS->install_path.($SETTINGS->modr=='yes' ? 'index.html' : 'index.php'));
      exit;
    }

    // Check for protection
    if ($SETTINGS->a_user && $SETTINGS->a_pass) {
      if (!isset($_SESSION[$lKey])) {
        $headerTitleText = $ps_header6.': '.$headerTitleText;
        include(PATH . 'control/header.php');
        $tpl = new Savant3();
        $tpl->assign('CSRF', (isset($_SESSION['token_' . sha1($SETTINGS->email . SECRET_KEY)]) ? $_SESSION['token_' . sha1($SETTINGS->email . SECRET_KEY)] : ''));
        $tpl->assign('VARS', $vars);
        $tpl->assign('CAPTCHA', _mmCaptcha($ps_contact10,$ps_contact11,'',$SETTINGS));
        $tpl->assign('H_URL', ($SETTINGS->modr=='yes' ? 'index.html' : 'index.php'));
        $tpl->assign('KEYWORDS', '');
        $tpl->assign('PLACEHOLDER', _mmHTML($ps_header13));
        $tpl->assign('FILTER_BY_TXT', $ps_search4);
        $tpl->assign('LOAD_CONTRIBUTORS', recipes::contributors('',$SETTINGS));
        $tpl->assign('LATEST_RECIPES_TXT', $ps_index4);
        $tpl->assign('LATEST_RECIPES', recipes::latest_popular('latest',$SETTINGS));
        $tpl->display('content/add-recipe-login.tpl.php');
        include(PATH . 'control/footer.php');
        exit;
      } else {
        if (isset($_SESSION[$lKey]) && $_SESSION[$lKey] == '') {
          header("Location: ?lo=yes");
          exit;
        }
      }
    }

    $headerTitleText = $ps_header6.': '.$headerTitleText;

    include(PATH . 'control/header.php');

    $tpl = new Savant3();
    $tpl->assign('IS_SENT', (isset($OK) ? true : false));
    $tpl->assign('A_URL', $SETTINGS->install_path . ($SETTINGS->modr=='yes' ? 'add-recipe.html' : '?p=add-recipe'));
    $tpl->assign('WELCOME_MSG', $ps_addrecipe);
    $tpl->assign('ADD_RECIPE_TXT', $ps_header6);
    $tpl->assign('ADD_RECIPE_TXT2', $ps_addrecipe3);
    $tpl->assign('ADD_RECIPE_TXT3', $ps_addrecipe4);
    $tpl->assign('ADD_RECIPE_TXT4', $ps_addrecipe5);
    $tpl->assign('ADD_RECIPE_TXT5', $ps_addrecipe6);
    $tpl->assign('CATEGORIES', categories::category_select(true,$SETTINGS));
    $tpl->assign('CAPTCHA', _mmCaptcha($ps_contact10,$ps_contact11,'add',$SETTINGS));
    $tpl->assign('NAME_TXT', $ps_contact6);
    $tpl->assign('EMAIL_TXT', $ps_contact7.' '.$ps_addrecipe2);
    $tpl->assign('RECIPE_NAME_TXT', $ps_addrecipe7);
    $tpl->assign('CAT_TXT', $ps_addrecipe8);
    $tpl->assign('INGREDIENTS_TXT', $ps_addrecipe9);
    $tpl->assign('INSTRUCTIONS_TXT', $ps_addrecipe10);
    $tpl->assign('SETTINGS', $SETTINGS);
    $tpl->assign('PICTURES', ($SETTINGS->maxImages>0 ? recipes::recipe_add_pictures($ps_addrecipe6,$SETTINGS) : ''));
    $tpl->assign('SEND_TXT', $ps_header6);
    $tpl->assign('H_URL', ($SETTINGS->modr=='yes' ? 'index.html' : 'index.php'));
    $tpl->assign('KEYWORDS', '');
    $tpl->assign('PLACEHOLDER', _mmHTML($ps_header13));
    $tpl->assign('FILTER_BY_TXT', $ps_search4);
    $tpl->assign('LOAD_CONTRIBUTORS', recipes::contributors('',$SETTINGS));
    $tpl->assign('LATEST_RECIPES_TXT', $ps_index4);
    $tpl->assign('VARS', $vars);
    $tpl->assign('LOGGED_IN', (isset($_SESSION[$lKey]) ? 'yes' : 'no'));
    $tpl->assign('CSRF', (isset($_SESSION['token_' . sha1($SETTINGS->email . SECRET_KEY)]) ? $_SESSION['token_' . sha1($SETTINGS->email . SECRET_KEY)] : ''));
    $tpl->assign('LATEST_RECIPES', recipes::latest_popular('latest',$SETTINGS));
    $tpl->display('content/add-recipe.tpl.php');

    include(PATH . 'control/footer.php');
    break;

  // content/about-us.tpl.php
  case 'about-us':

    $headerTitleText = $ps_header7.': '.$headerTitleText;

    include(PATH . 'control/header.php');

    $tpl = new Savant3();
    $tpl->assign('ABOUT_US_TXT', $ps_header7);
    $tpl->assign('LATEST_RECIPES_TXT', $ps_index4);
    $tpl->assign('LATEST_RECIPES', recipes::latest_popular('latest',$SETTINGS));
    $tpl->assign('MOST_POPULAR_TXT', $ps_index5);
    $tpl->assign('MOST_POPULAR', recipes::latest_popular('popular',$SETTINGS));
    $tpl->assign('LOAD_CONTRIBUTORS', recipes::contributors('',$SETTINGS));
    $tpl->assign('PLACEHOLDER', _mmHTML($ps_header13));
    $tpl->assign('FILTER_BY_TXT', $ps_search4);
    $tpl->assign('H_URL', ($SETTINGS->modr=='yes' ? 'index.html' : 'index.php'));
    $tpl->assign('KEYWORDS', '');
    $tpl->display('content/about-us.tpl.php');

    include(PATH . 'control/footer.php');
    break;

  // content/search.tpl.php
  case 'search-free-recipes':

    $_GET['cat'] = (isset($_GET['cat']) ? $_GET['cat'] : 'all');

    // Get filtering is done by default, so nothing else needed here..
    if (isset($_GET['keys']) && $_GET['keys']) {
      $searchKeys = rawurldecode($_GET['keys']);
    } else {
      header("Location: ".$SETTINGS->install_path . ($SETTINGS->modr=='yes' ? 'index.html' : 'index.php'));
      exit;
    }

    $sCount = categories::category_recipes($searchKeys,true,$SETTINGS);

    // Determine pagination..
    if ($SETTINGS->modr=='yes') {
      $pLink = $SETTINGS->install_path . 'search-free-recipes/' . urlencode($searchKeys) . '/' . (int)$_GET['cat'] . '/{page}/index.html';
    } else {
      $pLink = '?p=search-free-recipes&next=';
    }

    $pNumbers = new pages([
      'count' => $sCount,
      'text' => $vars['pagination'],
      'page' => $page,
      'limit' => $SETTINGS->total,
      'url' => $pLink,
      's' => $SETTINGS
    ]);

    $newsearchKeys = (substr($searchKeys,0,6) == 'chef::' ? substr($searchKeys,6) : $searchKeys);
    $headerTitleText = $ps_search.': '.$newsearchKeys.' - '.$headerTitleText;

    include(PATH . 'control/header.php');

    $tpl = new Savant3();
    $tpl->assign('SEARCH_TXT', $ps_search);
    $tpl->assign('SEARCH_RESULTS_TXT', str_replace(array('{keys}','{count}'),array($newsearchKeys,$sCount),$ps_search2));
    $tpl->assign('SEARCH_RESULTS', categories::category_recipes($searchKeys,false,$SETTINGS));
    $tpl->assign('COUNT', $sCount);
    $tpl->assign('PAGE_NUMBERS', $pNumbers->display());
    $tpl->assign('FILTER_BY_TXT', $ps_search3);
    $tpl->assign('LOAD_CATEGORIES', categories::category_search_select($searchKeys,$SETTINGS));
    $tpl->assign('FILTER_BY_TXT2', $ps_search4);
    $tpl->assign('LATEST_RECIPES_TXT', $ps_index4);
    $tpl->assign('LATEST_RECIPES', recipes::latest_popular('latest',$SETTINGS));
    $tpl->assign('LOAD_CONTRIBUTORS', recipes::contributors($searchKeys,$SETTINGS));
    $tpl->assign('H_URL', ($SETTINGS->modr=='yes' ? 'index.html' : 'index.php'));
    $tpl->assign('KEYWORDS', (isset($_GET['keys']) ? _mmHTML((substr($searchKeys,0,6) == 'chef::' ? '' : $newsearchKeys)) : ''));
    $tpl->assign('PLACEHOLDER', _mmHTML($ps_header13));
    $tpl->display('content/search.tpl.php');

    include(PATH . 'control/footer.php');
    break;

  // content/contact-us.tpl.php
  case 'contact-us':
  case 'contact-recipe':

    // Change data if coming from recipe page..
    if ($cmd=='contact-recipe' && isset($_GET['recipe'])) {
      $RECIPE  = _mmSQLTable('recipes','id',(int)$_GET['recipe']);
      if (isset($RECIPE->id)) {
        if ($SETTINGS->modr=='yes') {
          $link  = $SETTINGS->install_path . 'free-recipe/' . _mmURL($RECIPE->name) . '/' . $RECIPE->id . '/index.html';
        } else {
          $link  = $SETTINGS->install_path . '?p=recipe&amp;recipe='.$RECIPE->id;
        }
        $headerTitleText = $ps_recipe8.': '._mmHTML($RECIPE->name).' - '.$headerTitleText;
        // Auto fill in the comments box with the recipe name...
        $loadComms = str_replace(
          array('{recipe}','{url}'),
          array(_mmHTML($RECIPE->name),$link),
          $ps_contact17
        );
      }
    } else {
      $headerTitleText = $ps_header8.': '.$headerTitleText;
    }

    include(PATH . 'control/header.php');

    $tpl = new Savant3();
    if ($cmd=='contact-recipe') {
      $tpl->assign('C_URL', $SETTINGS->install_path . ($SETTINGS->modr=='yes' ? 'contact-recipe/' . (int)$_GET['recipe'] . '/index.html' : '?p=contact-recipe&amp;recipe=' . (int)$_GET['recipe']));
    } else {
      $tpl->assign('C_URL', $SETTINGS->install_path . ($SETTINGS->modr=='yes' ? 'contact-us.html' : '?p=contact-us'));
    }
    $tpl->assign('CONTACT_TXT', (isset($_GET['recipe']) ? str_replace('{recipe}',_mmHTML($RECIPE->name),$ps_contact16) : $ps_contact5));
    $tpl->assign('NAME_TXT', $ps_contact6);
    $tpl->assign('EMAIL_TXT', $ps_contact7);
    $tpl->assign('COMMENTS_TXT', $ps_contact8);
    $tpl->assign('COMMENTS', (isset($loadComms) ? $loadComms : ''));
    $tpl->assign('CAPTCHA', _mmCaptcha($ps_contact10,$ps_contact11,'',$SETTINGS));
    $tpl->assign('SETTINGS', $SETTINGS);
    $tpl->assign('SEND_TXT', $ps_contact9);
    $tpl->assign('CSRF', (isset($_SESSION['token_' . sha1($SETTINGS->email . SECRET_KEY)]) ? $_SESSION['token_' . sha1($SETTINGS->email . SECRET_KEY)] : ''));
    $tpl->assign('LOAD_CONTRIBUTORS', recipes::contributors('',$SETTINGS));
    $tpl->assign('PLACEHOLDER', _mmHTML($ps_header13));
    $tpl->assign('FILTER_BY_TXT', $ps_search4);
    $tpl->assign('H_URL', ($SETTINGS->modr=='yes' ? 'index.html' : 'index.php'));
    $tpl->assign('KEYWORDS', '');
    $tpl->assign('LATEST_RECIPES_TXT', $ps_index4);
    $tpl->assign('LATEST_RECIPES', recipes::latest_popular('latest',$SETTINGS));
    $tpl->assign('MOST_POPULAR_TXT', $ps_index5);
    $tpl->assign('MOST_POPULAR', recipes::latest_popular('popular',$SETTINGS));
    $tpl->display('content/contact-us.tpl.php');

    include(PATH . 'control/footer.php');
    break;

  // content/printer-friendly.tpl.php
  case 'print':

    if (!isset($_GET['recipe'])) {
      header("Location: ".$SETTINGS->install_path.($SETTINGS->modr=='yes' ? 'index.html' : 'index.php'));
      exit;
    }

    _mmDigit($_GET['recipe']);

    // Get recipe information..
    $RECIPE  = _mmSQLTable('recipes','id',$_GET['recipe']);

    // Is recipe enabled..
    if ($RECIPE->enRecipe=='no' || $RECIPE->isApproved=='yes') {
      header("Location: ".$SETTINGS->install_path.($SETTINGS->modr=='yes' ? '404.html' : 'index.php?p=404'));
      exit;
    }

    $tpl = new Savant3();
    $tpl->assign('BASE_PATH', $SETTINGS->install_path);
    $tpl->assign('CHARSET', $charset);
    $tpl->assign('RECIPE', $RECIPE);
    $tpl->assign('BY', str_replace(array('{website_name}','{website_url}'),array(_mmHTML($SETTINGS->website),$SETTINGS->install_path),$ps_recipe36));
    $tpl->assign('INGREDIENTS_TXT', $ps_recipe11);
    $tpl->assign('INSTRUCTIONS_TXT', $ps_recipe12);
    $tpl->assign('DATE_BAR_TXT', ($RECIPE->submitted_by ? $ps_recipe34.' ' . _mmHTML($RECIPE->submitted_by) . ' | ' : '') . $ps_recipe35 . ' ' . $RECIPE->adate);
    $tpl->display('content/printer-friendly.tpl.php');

    break;

  // RSS feed..
  case 'rss-feed':
  case 'rss-cat-feed':
    
    // Is cat defined..
    $url = '';
    if (isset($_GET['cat'])) {
      $CAT = _mmSQLTable('categories','id',(int)$_GET['cat']);
      if ($CAT->enCat=='no') {
        header("Location: ".$SETTINGS->install_path.($SETTINGS->modr=='yes' ? '404.html' : 'index.php?p=404'));
        exit;
      }
      if ($CAT->isParent=='no') {
        $thisParent = _mmSQLTable('categories','id',$CAT->childOf);
        if ($thisParent->enCat=='no') {
          header("Location: ".$SETTINGS->install_path.($SETTINGS->modr=='yes' ? '404.html' : 'index.php?p=404'));
          exit;
        }
      }
      if (!isset($CAT->id) && !isset($thisParent->id)) {
        header("Location: ".$SETTINGS->install_path.($SETTINGS->modr=='yes' ? '404.html' : 'index.php?p=404'));
        exit;
      }
      // Cat name..
      $CATNAME = (isset($thisParent->catname) ? _mmHTML($thisParent->catname) . '/' . _mmHTML($CAT->catname) : _mmHTML($CAT->catname));
      // Cat url..
      if ($SETTINGS->modr=='yes') {
        $url = $SETTINGS->install_path . 'category/' . (isset($thisParent->catname) ? _mmURL($thisParent->catname) . '/' : '') . _mmURL($CAT->catname) . '/' . (int)$_GET['cat'] . '/1/index.html';
      } else {
        $url = $SETTINGS->install_path . '?p=category&amp;cat='.(int)$_GET['cat'];
      }
    }
    // Define vars..
    $rss_feed    = '';
    // Open channel..
    $rss_feed = rss::rss_open_channel();
    // Feed info..
    if (isset($_GET['cat'])) {
      $rss_feed .= rss::rss_feed_info(
        str_replace(array('{website_name}','{category}'),array($SETTINGS->website,$CATNAME),$msg_rss4),
        $url,
        RSS_BUILD_DATE_FORMAT,
        str_replace("{website_name}",$SETTINGS->website,$msg_rss2),
        $SETTINGS->website,
        $SETTINGS->install_path.($SETTINGS->modr=='yes' ? 'rss-cat-feed/' . (int)$_GET['cat'] . '/.html' : '?p=rss-cat-feed&amp;cat=' . (int)$_GET['cat'])
      );
    } else {
      $rss_feed .= rss::rss_feed_info(
        str_replace("{website_name}",$SETTINGS->website,$msg_rss),
        ($SETTINGS->modr=='yes' ? $SETTINGS->install_path . 'index.html' : $SETTINGS->install_path . 'index.php'),
        RSS_BUILD_DATE_FORMAT,
        str_replace("{website_name}",$SETTINGS->website,$msg_rss2),
        $SETTINGS->website,
        $SETTINGS->install_path . ($SETTINGS->modr=='yes' ? 'rss-feed.html' : '?p=rss-feed')
      );
    }
    // Get latest recipes..
    $rss_feed .= rss::rss_latest_recipes(RSS_BUILD_DATE_FORMAT,(isset($_GET['cat']) ? (int)$_GET['cat'] : 0),$SETTINGS);
    // Close channel..
    $rss_feed .= rss::rss_close_channel();
    // Display RSS feed..
    header('Content-Type: text/xml');
    echo _mmClean(trim($rss_feed));
    break;

  case 'captcha':
    // Change parameters to suit your own design/colors..
    // Additional parameters in 'control/classes/class.captcha.php'..
    captcha::show(
      captcha::code()
    );
    break;
}

?>
