<?php

/* INSTALLER
==============================================*/

define('PATH', __dir__.'/');
define('IPATH', __dir__ . '/../');

// Check cfg
if (!file_exists(IPATH . 'control/_cfg.php')) {
  die('Config file missing, please read installation instructions');
}

include(IPATH . 'control/_cfg.php');
date_default_timezone_set((TIMEZONE ? TIMEZONE: (function_exists('date_default_timezone_get') ? date_default_timezone_get() : 'Europe/London')));

if (version_compare(phpversion(), '7.0', '<')) {
  die('PHP version too old, PHPv7 or higher required');
}

// ENABLE DEBUGGER
echo (!function_exists('json_decode') ? die('The JSON functions are not enabled on your server. Enable and restart server. If you are unsure please contact your host.') : '');

include(IPATH . 'control/options.php');
if (version_compare(PHP_VERSION, '8.0.0') >= 0) {
  include(IPATH . 'control/lib/tracy/vendor/tracy/tracy/src/tracy.php');
}
use Tracy\Debugger;
if (version_compare(PHP_VERSION, '8.0.0') >= 0) {
  // For development, report everything and enable tracy bar
  Debugger::$showBar = (defined('DEVELOPMENT_ENV') ? true : false);
  Debugger::$strictMode = (defined('DEVELOPMENT_ENV') ? true : false);
  Debugger::enable(Debugger::DEVELOPMENT, IPATH . 'logs');
}

include(PATH . 'lang.php');

$stage1  = true;
$stage2  = false;
$stage3  = false;
$report  = [];
$table   = [];
$count   = 0;

// Install tables..
if (isset($_POST['one'])) {
 $stage1 = false;

 // Install table...categories..
 mysqli_query($GLOBALS["___mysqli_ston"], "DROP TABLE IF EXISTS " . DB_PREFIX . "categories");
 $query = mysqli_query($GLOBALS["___mysqli_ston"], "
 CREATE TABLE " . DB_PREFIX . "categories (
  `id` int(10) unsigned NOT NULL auto_increment,
  `catname` varchar(200) NOT NULL,
  `comments` text default null,
  `isParent` enum('yes','no') NOT NULL default 'yes',
  `childOf` int(6) NOT NULL default '0',
  `metaDesc` text default null,
  `metaKeys` text default null,
  `enCat` enum('yes','no') NOT NULL default 'yes',
  PRIMARY KEY (`id`),
  KEY `isParent` (`isParent`),
  KEY `childOf` (`childOf`),
  KEY `enCat` (`enCat`)
 ) ENGINE=MyISAM  DEFAULT CHARSET=utf8mb4
 ");

 $report[] = ($query ? $setup9 : $setup10);
 $table[]  = DB_PREFIX."categories";

 // Install table...comments..
 mysqli_query($GLOBALS["___mysqli_ston"], "DROP TABLE IF EXISTS " . DB_PREFIX . "comments");
 $query = mysqli_query($GLOBALS["___mysqli_ston"], "
 CREATE TABLE " . DB_PREFIX . "comments (
  `id` int(10) unsigned NOT NULL auto_increment,
  `recipe` int(8) NOT NULL default '0',
  `comment` text default null,
  `leftBy` varchar(250) NOT NULL default '',
  `email` varchar(250) NOT NULL default '',
  `addDate` date default null,
  `isApproved` enum('yes','no') NOT NULL default 'no',
  `ipAddresses` text default null,
  PRIMARY KEY (`id`),
  KEY `recipe` (`recipe`)
 ) ENGINE=MyISAM  DEFAULT CHARSET=utf8mb4
 ");

 $report[] = ($query ? $setup9 : $setup10);
 $table[]  = DB_PREFIX."comments";

 // Install table...pictures..
 mysqli_query($GLOBALS["___mysqli_ston"], "DROP TABLE IF EXISTS " . DB_PREFIX . "pictures");
 $query = mysqli_query($GLOBALS["___mysqli_ston"], "
 CREATE TABLE " . DB_PREFIX . "pictures (
  `id` int(10) unsigned NOT NULL auto_increment,
  `recipe` int(8) NOT NULL default '0',
  `picPath` varchar(100) NOT NULL default '',
  PRIMARY KEY (`id`),
  KEY `recipe` (`recipe`)
 ) ENGINE=MyISAM  DEFAULT CHARSET=utf8mb4
 ");

 $report[] = ($query ? $setup9 : $setup10);
 $table[]  = DB_PREFIX."pictures";

 // Install table...recipes..
 mysqli_query($GLOBALS["___mysqli_ston"], "DROP TABLE IF EXISTS " . DB_PREFIX . "recipes");
 $query = mysqli_query($GLOBALS["___mysqli_ston"], "
 CREATE TABLE " . DB_PREFIX . "recipes (
  `id` int(10) unsigned NOT NULL auto_increment,
  `name` varchar(250) NOT NULL default '',
  `ingredients` text default null,
  `instructions` text default null,
  `submitted_by` varchar(100) NOT NULL default '',
  `addDate` date default null,
  `hits` int(7) NOT NULL default '0',
  `metaDesc` text default null,
  `metaKeys` text default null,
  `enComments` enum('yes','no') NOT NULL default 'yes',
  `enRecipe` enum('yes','no') NOT NULL default 'yes',
  `isApproved` enum('yes','no') NOT NULL default 'no',
  `ipAddresses` text default null,
  `email` varchar(250) NOT NULL default '',
  `rss_date` varchar(35) NOT NULL default '',
  PRIMARY KEY (`id`),
  KEY `enRecipe` (`enRecipe`),
  KEY `isApproved` (`isApproved`),
  FULLTEXT KEY `name` (`name`,`ingredients`,`instructions`),
  FULLTEXT KEY `submitted_by` (`submitted_by`)
 ) ENGINE=MyISAM  DEFAULT CHARSET=utf8mb4
 ");

 $report[] = ($query ? $setup9 : $setup10);
 $table[]  = DB_PREFIX."recipes";
 
 // Install table...recipes..
 mysqli_query($GLOBALS["___mysqli_ston"], "DROP TABLE IF EXISTS " . DB_PREFIX . "recipe_cats");
 $query = mysqli_query($GLOBALS["___mysqli_ston"], "
 CREATE TABLE " . DB_PREFIX . "recipe_cats (
  `id` INT(10) UNSIGNED NOT NULL AUTO_INCREMENT,
	`recipe` INT(8) NOT NULL DEFAULT '0',
	`category` INT(8) NOT NULL DEFAULT '0',
	PRIMARY KEY (`id`),
  INDEX `recipe` (`recipe`),
  INDEX `category` (`category`)
 ) ENGINE=MyISAM  DEFAULT CHARSET=utf8mb4
 ");

 $report[] = ($query ? $setup9 : $setup10);
 $table[]  = DB_PREFIX."recipe_cats";

 // Install table...settings..
 mysqli_query($GLOBALS["___mysqli_ston"], "DROP TABLE IF EXISTS " . DB_PREFIX . "settings");
 $query = mysqli_query($GLOBALS["___mysqli_ston"], "
 CREATE TABLE " . DB_PREFIX . "settings (
  `website` varchar(100) NOT NULL default '',
  `email` varchar(250) NOT NULL default '',
  `language` varchar(30) NOT NULL default '',
  `install_path` varchar(250) NOT NULL default '',
  `total` int(3) NOT NULL default '0',
  `smtp` enum('yes','no') NOT NULL default 'no',
  `smtp_host` varchar(150) NOT NULL default 'localhost',
  `smtp_user` varchar(150) NOT NULL default '',
  `smtp_pass` varchar(150) NOT NULL default '',
  `smtp_port` varchar(10) NOT NULL default '25',
  `smtp_fname` varchar(150) NOT NULL default '',
  `smtp_femail` varchar(150) NOT NULL default '',
  `modr` enum('yes','no') NOT NULL default 'no',
  `server_path` varchar(250) NOT NULL default '',
  `metaDesc` text default null,
  `metaKeys` text default null,
  `enCommApp` enum('yes','no') NOT NULL default 'yes',
  `enRecApp` enum('yes','no') NOT NULL default 'yes',
  `enSpam` enum('yes','no') NOT NULL default 'yes',
  `maxImages` int(3) NOT NULL default '0',
  `autoResize` varchar(50) NOT NULL default '640,480',
  `maxFileSize` varchar(100) NOT NULL default '256000',
  `enRSS` enum('yes','no') NOT NULL default 'yes',
  `addRecipe` enum('no','yes') not null default 'yes',
  `a_user` varchar(250) not null default '',
  `a_pass` varchar(250) not null default '',
  `menu` enum('open','closed') NOT NULL DEFAULT 'open',
  PRIMARY KEY  (`email`)
 ) ENGINE=MyISAM DEFAULT CHARSET=utf8mb4
 ");

 $report[] = ($query ? $setup9 : $setup10);
 $table[]  = DB_PREFIX."settings";

 $stage2 = true;

}

// Install data..
if (isset($_POST['two'])) {
  // Install cats..
  if (isset($_POST['cats'])) {
    mysqli_query($GLOBALS["___mysqli_ston"], "TRUNCATE TABLE " . DB_PREFIX . "categories");
    mysqli_query($GLOBALS["___mysqli_ston"], "INSERT INTO `" . DB_PREFIX . "categories` (
    `id`, `catname`, `comments`, `isParent`, `childOf`, `metaDesc`, `metaKeys`, `enCat`) VALUES
    (9, 'Poultry', '', 'yes', 0, '', '', 'yes'),
    (10, 'Chicken', '', 'no', 9, '', '', 'yes'),
    (11, 'Turkey', '', 'no', 9, '', '', 'yes'),
    (12, 'Duck', '', 'no', 9, '', '', 'yes'),
    (13, 'Goose', '', 'no', 9, '', '', 'yes'),
    (14, 'Lamb', '', 'yes', 0, '', '', 'yes'),
    (15, 'Chops', '', 'no', 14, '', '', 'yes'),
    (16, 'Shank', '', 'no', 14, '', '', 'yes'),
    (17, 'Leg', '', 'no', 14, '', '', 'yes'),
    (18, 'Roast', '', 'no', 14, '', '', 'yes'),
    (19, 'Fish', '', 'yes', 0, '', '', 'yes'),
    (20, 'Salmon', '', 'no', 19, '', '', 'yes'),
    (21, 'Trout', '', 'no', 19, '', '', 'yes'),
    (22, 'Tuna', '', 'no', 19, '', '', 'yes'),
    (23, 'Smoked', '', 'no', 19, '', '', 'yes'),
    (24, 'Bread and Cakes', '', 'yes', 0, '', '', 'yes'),
    (25, 'Biscuits', '', 'no', 24, '', '', 'yes'),
    (26, 'Pancakes', '', 'no', 24, '', '', 'yes'),
    (27, 'Muffins', '', 'no', 24, '', '', 'yes'),
    (28, 'Scones', '', 'no', 24, '', '', 'yes'),
    (29, 'Rice and Grains', '', 'yes', 0, '', '', 'yes'),
    (30, 'Risotto', '', 'no', 29, '', '', 'yes'),
    (31, 'Polenta', '', 'no', 29, '', '', 'yes'),
    (32, 'Couscous', '', 'no', 29, '', '', 'yes'),
    (33, 'Eggs and Dairy', '', 'yes', 0, '', '', 'yes'),
    (34, 'Quiche', '', 'no', 33, '', '', 'yes'),
    (35, 'Souffle', '', 'no', 33, '', '', 'yes'),
    (36, 'Ice cream', '', 'no', 33, '', '', 'yes'),
    (37, 'Nuts and seeds', '', 'yes', 0, '', '', 'yes'),
    (38, 'Almonds', '', 'no', 37, '', '', 'yes'),
    (39, 'Peanuts', '', 'no', 37, '', '', 'yes'),
    (40, 'Pine Nuts', '', 'no', 37, '', '', 'yes'),
    (41, 'Poppy', '', 'no', 37, '', '', 'yes'),
    (42, 'Game', '', 'yes', 0, '', '', 'yes'),
    (43, 'Pheasant', '', 'no', 42, '', '', 'yes'),
    (44, 'Venison', '', 'no', 42, '', '', 'yes'),
    (45, 'Quail', '', 'no', 42, '', '', 'yes'),
    (46, 'Wild Boar', '', 'no', 42, '', '', 'yes'),
    (47, 'Fruit', '', 'yes', 0, '', '', 'yes'),
    (48, 'Apple', '', 'no', 47, '', '', 'yes'),
    (49, 'Lemon', '', 'no', 47, '', '', 'yes'),
    (50, 'Bananas', '', 'no', 47, '', '', 'yes'),
    (51, 'Beef', 'comments here..', 'yes', 0, '', '', 'yes'),
    (52, 'Mince', '', 'no', 51, 'mince..', 'mince..', 'yes'),
    (53, 'Steak', '', 'no', 51, '', '', 'yes'),
    (54, 'Roast', '', 'no', 51, '', '', 'yes'),
    (56, 'Pork', '', 'yes', 0, '', '', 'yes'),
    (57, 'Fillet', '', 'no', 56, '', '', 'yes'),
    (58, 'Belly', '', 'no', 56, '', '', 'yes'),
    (59, 'Chops', '', 'no', 56, '', '', 'yes'),
    (60, 'Roast', '', 'no', 56, '', '', 'yes'),
    (61, 'Shellfish', '', 'yes', 0, '', '', 'yes'),
    (62, 'Prawns', '', 'no', 61, '', '', 'yes'),
    (63, 'Lobster', '', 'no', 61, '', '', 'yes'),
    (64, 'Mussels', '', 'no', 61, '', '', 'yes'),
    (65, 'Squid', '', 'no', 61, '', '', 'yes'),
    (66, 'Pasta & Noodles', '', 'yes', 0, '', '', 'yes'),
    (67, 'Spaghetti', '', 'no', 66, '', '', 'yes'),
    (68, 'Lasagne', '', 'no', 66, '', '', 'yes'),
    (69, 'Noodles', '', 'no', 66, '', '', 'yes'),
    (70, 'Ravioli', '', 'no', 66, '', '', 'yes'),
    (71, 'Pulses and Soya', '', 'yes', 0, '', '', 'yes'),
    (72, 'Chickpeas', '', 'no', 71, '', '', 'yes'),
    (73, 'Lentils', '', 'no', 71, '', '', 'yes'),
    (74, 'Tofu', '', 'no', 71, '', '', 'yes'),
    (80, 'Vegetables', '', 'yes', 0, '', '', 'yes'),
    (81, 'Tomatoes', '', 'no', 80, '', '', 'yes'),
    (82, 'Leeks', '', 'no', 80, '', '', 'yes'),
    (83, 'Potatoes', '', 'no', 80, '', '', 'yes'),
    (84, 'Squash', '', 'no', 80, '', '', 'yes'),
    (85, 'Offal', '', 'yes', 0, '', '', 'yes'),
    (86, 'Liver', '', 'no', 85, '', '', 'yes'),
    (87, 'Kidney', '', 'no', 85, '', '', 'yes'),
    (88, 'Sweetbreads', '', 'no', 85, '', '', 'yes')") or die(mysqli_error($GLOBALS["___mysqli_ston"]));
  }
  
  // Settings..
  $host = 'http://www.example.com/recipes';
  if (isset($_SERVER['HTTP_HOST'], $_SERVER['PHP_SELF'])) {
    $host = 'http' . (isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] == 'on' ? 's' : '') . '://' . $_SERVER['HTTP_HOST'] . substr($_SERVER['PHP_SELF'], 0, strpos($_SERVER['PHP_SELF'], 'install') - 1) . '/';
  }
  $path = substr(dirname(__file__), 0, strpos(dirname(__file__), 'install')-1) . DIRECTORY_SEPARATOR;
  mysqli_query($GLOBALS["___mysqli_ston"], "TRUNCATE TABLE " . DB_PREFIX . "settings");
  mysqli_query($GLOBALS["___mysqli_ston"], "INSERT INTO " . DB_PREFIX . "settings (
  `website`, `email`, `language`, `install_path`, `total`, `smtp`, `smtp_host`, `smtp_user`,
  `smtp_pass`, `smtp_port`, `modr`, `server_path`, `metaDesc`, `metaKeys`, `enCommApp`, `enRecApp`,
  `enSpam`, `maxImages`, `autoResize`, `maxFileSize`, `enRSS`, `addRecipe`
  ) VALUES(
  'Recipe Box', 'email@example.com', 'english.php', '" . mysqli_real_escape_string($GLOBALS["___mysqli_ston"], $host) . "', '20', 'no',
  'localhost', '', '', '587', 'no', '" . mysqli_real_escape_string($GLOBALS["___mysqli_ston"], $path) . "', 'Meta description here..', 'Meta keywords here',
  'yes', 'yes', 'yes', '3', '640,480', '256000', 'yes', 'yes'
  )") or die(mysqli_error($GLOBALS["___mysqli_ston"]));


  $stage1 = false;
  $stage2 = false;
  $stage3 = true;
}

?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN"
"http://www.w3.org/TR/html4/loose.dtd">
<head>
<meta http-equiv="content-type" content="text/html; charset=<?php echo $charset; ?>">
<title><?php echo $setup; ?></title>
<link href="css/style.css" rel="stylesheet" type="text/css">
<link rel="icon" href="images/favicon.ico">
</head>

<body>
<form method="post" action="index.php">
<div align="center">
<table width="600" cellspacing="0" cellpadding="0" class="mainTable">
<tr>
  <td align="center" class="headCell">- <?php echo $setup; ?> -</td>
</tr>
<?php
if ($stage1)
{
if (function_exists('gd_info')) {
  $GDArray = gd_info();
}
?>
<tr>
  <td align="center" class="pad" style="padding:20px"><br><?php echo $setup2; ?><br><br>
  <table width="100%" cellspacing="0" cellpadding="0" class="areaTable">
  <tr>
    <td class="pad" width="60%"><b><?php echo $setup3; ?></b></td>
    <td class="pad" width="40%" style="text-align:right"><span class="info"><?php echo DB_HOST; ?></span></td>
  </tr>
  <tr>
    <td class="pad"><b><?php echo $setup4; ?></b></td>
    <td class="pad" style="text-align:right"><span class="info"><?php echo DB_NAME; ?></span></td>
  </tr>
  <tr>
    <td class="pad"><b><?php echo $setup5; ?></b></td>
    <td class="pad" style="text-align:right"><span class="info"><?php echo DB_USER; ?></span></td>
  </tr>
  <tr>
    <td class="pad"><b><?php echo $setup6; ?></b></td>
    <td class="pad" style="text-align:right"><span class="info"><?php echo DB_PASS; ?></span></td>
  </tr>
  <tr>
    <td class="pad"><b><?php echo $setup7; ?></b></td>
    <td class="pad" style="text-align:right"><span class="info"><?php echo DB_PREFIX; ?></span></td>
  </tr>
  </table>
  </td>
</tr>
<tr>
  <td align="center" class="pad" style="padding:20px"><?php echo $setup17; ?>:<br><br>
  <table width="100%" cellspacing="0" cellpadding="0" class="areaTable">
  <tr>
    <td class="pad" width="60%"><b><?php echo $setup16; ?></b></td>
    <td class="pad" width="40%" style="text-align:right"><span class="info">v<?php echo phpversion(); ?> - <b><?php echo (phpversion()>='7' ? $setup19 : $setup22); ?></b></span></td>
  </tr>
  <tr>
    <td class="pad"><b><?php echo $setup15; ?></b></td>
    <td class="pad" style="text-align:right"><span class="info"><?php echo '<b>'.$setup19.'</b>'; ?></span></td>
  </tr>
  </table>
  <?php
  if (phpversion()>='7')
  {
  ?>
  <p class="button"><br /><input class="formButton" name="one" type="submit" value="<?php echo $setup8; ?> &raquo;" title="<?php echo $setup8; ?>" /></p>
  <?php
  } else {
  ?>
  <p class="button" style="color:red;font-size:16px;margin-top:5px"><b><?php echo $setup23; ?></b></p>
  <?php
  }
  ?>
  </td>
</tr>
<?php
}
if ($stage2 && !$stage1)
{
?>
<tr>
  <td align="center" class="pad" style="padding:20px"><br><?php echo $setup14; ?><br><br>
  <table width="100%" cellspacing="0" cellpadding="0" class="areaTable">
  <?php

  // Show results..
  for ($i=0; $i<count($report); $i++)
  {
  ?>
  <tr>
    <td class="pad" width="60%"><b><?php echo $table[$i]; ?></b></td>
    <td class="pad" width="40%" style="text-align:right"><span class="info"><?php echo $report[$i]; ?></span></td>
  </tr>
  <?php
  }

  ?>
  </table>
  <?php
  if (array_search($setup10,$report)===FALSE)
  {
  ?>
</td>
</tr>
<tr>
  <td align="center" class="pad" style="padding:20px"><?php echo $setup18; ?>:<br><br>
  <table width="100%" cellspacing="0" cellpadding="0" class="areaTable">
  <tr>
    <td class="pad" width="60%"><input type="checkbox" name="cats" value="1" /></td>
    <td class="pad" width="40%" style="text-align:right"><span class="info"><?php echo $setup25; ?></span></td>
  </tr>
  </table>
  <p class="button"><br /><input class="formButton" name="two" type="submit" value="<?php echo $setup12; ?> &raquo;" title="<?php echo $setup12; ?>" /></p>
  <?php
  }
  else
  {
    echo '<span class="error_info"><br>'.$setup11.'</span>';
  }
  ?>
  </td>
</tr>
<?php
}
if ($stage3 && (!$stage1 && !$stage2))
{
?>
<tr>
  <td align="center" class="pad2" style="padding:20px"><?php echo $setup13; ?><br><br>
  </td>
</tr>
<?php
}
?>
</table>
</div>
</form>
</body>
</html>
